# PaperCandy

**PaperCandy** is a loosely coupled lightweight framework for deep learning papers. It provides a series of auxiliary tools for rapid rebuilding and writing papers, including universal data loader, and automatically generating network structure and training process diagram. So far support PyTorch as the only front-end framework.

## Installation

### For Windows

```shell
pip install paper-candy
```

### For Linux & MacOS

```shell
pip3 install paper-candy
```
